@@ -22,7 +22,9 @@
 # Imports
 #
 from typing import Any, Callable, Optional, Union
+
 import pyrogram
+
 from telegram_payment_bot.utils.utils import Utils
 from telegram_payment_bot.utils.wrapped_list import WrappedList
 
@@ -93,6 +95,9 @@ class CommandData:
     # Constructor
     def __init__(self,
                  message: pyrogram.types.Message) -> None:
+        if message.command is None or message.chat is None:
+            raise ValueError("Invalid command")
+
         self.cmd_name = message.command[0]
         self.cmd_params = CommandParametersList()
         self.cmd_params.AddMultiple(message.command[1:])
